==> mcp_server_googlesearch-0.1.0-py3-none-any.whl: mcp_server_googlesearch/search_handler.py <==
"""Google search handler for MCP server."""

import asyncio
import logging
from typing import List
from googlesearch import search
from .models import SearchResult
from .error_handler import log_error

# Set up logging
logger = logging.getLogger(__name__)


async def execute_google_search(query: str, num_results: int = 10) -> List[SearchResult]:
    """Execute a Google search and return structured results.
    
    Args:
        query: The search query to execute
        num_results: Number of search results to return (1-50)
        
    Returns:
        List of SearchResult objects
        
    Raises:
        ValueError: If query is empty or num_results is invalid
        Exception: If search execution fails
    """
    # Validate input parameters
    if not query or not isinstance(query, str) or not query.strip():
        raise ValueError("Query must be a non-empty string")
    
    if not isinstance(num_results, int) or num_results < 1 or num_results > 50:
        raise ValueError("num_results must be an integer between 1 and 50")
    
    try:
        # Execute search in a thread pool to avoid blocking
        loop = asyncio.get_event_loop()
        search_results = await loop.run_in_executor(
            None, 
            lambda: search(query.strip(), num_results=num_results, advanced=True)
        )
        
        # Convert to our SearchResult objects
        results = []
        for result in search_results:
            # Handle cases where some properties might be missing
            title = getattr(result, 'title', '') or 'No title'
            url = getattr(result, 'url', '') or 'No URL'
            description = getattr(result, 'description', '') or ''
            
            try:
                search_result = SearchResult(title=title, url=url, description=description)
                results.append(search_result)
            except ValueError as e:
                # Skip invalid results but log the issue
                log_error(f"Skipping invalid search result", e)
                continue
        
        return results
        
    except Exception as e:
        # Re-raise with more context
        raise Exception(f"Google search failed: {str(e)}") from e


def validate_search_parameters(query: str, num_results: int) -> None:
    """Validate search parameters.
    
    Args:
        query: The search query
        num_results: Number of results requested
        
    Raises:
        ValueError: If parameters are invalid
    """
    if not query or not isinstance(query, str) or not query.strip():
        raise ValueError("Query must be a non-empty string")
    
    if not isinstance(num_results, int):
        raise ValueError("num_results must be an integer")
    
    if num_results < 1 or num_results > 50:
        raise ValueError("num_results must be between 1 and 50")

==> mcp_server_googlesearch-0.1.1-py3-none-any.whl: mcp_server_googlesearch/search_handler.py <==
"""Google search handler for MCP server."""

import asyncio
import logging
from typing import List
from googlesearch import search
from .models import SearchResult
from .error_handler import log_error

# Set up logging
logger = logging.getLogger(__name__)


async def execute_google_search(query: str, num_results: int = 10, lang: str = None, region: str = None) -> List[SearchResult]:
    """Execute a Google search and return structured results.
    
    Args:
        query: The search query to execute
        num_results: Number of search results to return (1-50)
        lang: Language for search results (optional)
        region: Country/region for search results (optional)
        
    Returns:
        List of SearchResult objects
        
    Raises:
        ValueError: If query is empty or num_results is invalid
        Exception: If search execution fails
    """
    # Validate input parameters
    if not query or not isinstance(query, str) or not query.strip():
        raise ValueError("Query must be a non-empty string")
    
    if not isinstance(num_results, int) or num_results < 1 or num_results > 50:
        raise ValueError("num_results must be an integer between 1 and 50")
    
    try:
        # Build search parameters dynamically
        # First parameter is the query string (positional)
        search_params = {
            "num_results": num_results,
            "advanced": True
        }
        
        # Add optional parameters only if they are provided
        if lang is not None:
            search_params["lang"] = lang
        if region is not None:
            search_params["region"] = region
        
        # Execute search in a thread pool to avoid blocking
        loop = asyncio.get_event_loop()
        search_results = await loop.run_in_executor(
            None, 
            lambda: search(query.strip(), **search_params)
        )
        
        # Convert to our SearchResult objects
        results = []
        for result in search_results:
            # Handle cases where some properties might be missing
            title = getattr(result, 'title', '') or 'No title'
            url = getattr(result, 'url', '') or 'No URL'
            description = getattr(result, 'description', '') or ''
            
            try:
                search_result = SearchResult(title=title, url=url, description=description)
                results.append(search_result)
            except ValueError as e:
                # Skip invalid results but log the issue
                log_error(f"Skipping invalid search result", e)
                continue
        
        return results
        
    except Exception as e:
        # Re-raise with more context
        raise Exception(f"Google search failed: {str(e)}") from e


def validate_search_parameters(query: str, num_results: int) -> None:
    """Validate search parameters.
    
    Args:
        query: The search query
        num_results: Number of results requested
        
    Raises:
        ValueError: If parameters are invalid
    """
    if not query or not isinstance(query, str) or not query.strip():
        raise ValueError("Query must be a non-empty string")
    
    if not isinstance(num_results, int):
        raise ValueError("num_results must be an integer")
    
    if num_results < 1 or num_results > 50:
        raise ValueError("num_results must be between 1 and 50")
